@@ -29,17 +29,18 @@ build_time_vars = {'ABIFLAGS': '',
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
            '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
-           '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic -O3 '
+           '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+           '-Wformat -Werror=format-security         -fstack-clash-protection '
+           '-fcf-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
            '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
-           '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-fcf-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto',
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-flto=auto',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -49,7 +50,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection '
                      '-fcf-protection -g '
-                     '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                     '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                      '-flto=auto -ffat-lto-objects',
  'CONFIGURE_CFLAGS_NODIST': '-fno-semantic-interposition -flto '
                             '-fuse-linker-plugin -ffat-lto-objects '
@@ -74,8 +75,8 @@ build_time_vars = {'ABIFLAGS': '',
                 '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection '
                 '-fcf-protection -g '
-                '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
-                "-ffat-lto-objects' "
+                '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+                "-flto=auto -ffat-lto-objects' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-flto=auto'",
  'CONFINCLUDEDIR': '/usr/include',
@@ -683,19 +684,19 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                              '-Werror=format-security         '
                              '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-flto=auto -ffat-lto-objects -march=x86-64 '
                              '-mtune=generic -O3 -pipe -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-flto=auto -march=x86-64 -mtune=generic -O3 '
                              '-pipe -fno-plt -fexceptions         '
                              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                              '-Werror=format-security         '
                              '-fstack-clash-protection -fcf-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-flto=auto -fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g -std=c99 -Wextra '
@@ -709,17 +710,18 @@ build_time_vars = {'ABIFLAGS': '',
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
               '-fcf-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
-              '-ffat-lto-objects -march=x86-64 -mtune=generic -O3 -pipe '
-              '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
-              '-fcf-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto '
-              '-march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+              '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic -O3 '
+              '-pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+              '-Wformat -Werror=format-security         '
+              '-fstack-clash-protection -fcf-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+              '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
               '-fcf-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug -flto=auto',
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+              '-flto=auto',
  'PY_CFLAGS_NODIST': '-fno-semantic-interposition -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -flto-partition=none -g -std=c99 '
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
@@ -732,18 +734,18 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-flto=auto -ffat-lto-objects -march=x86-64 -mtune=generic '
                    '-O3 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe -fno-plt '
                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
                    '-fcf-protection -g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-flto=auto -fno-semantic-interposition -flto '
                    '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
                    '-g -std=c99 -Wextra -Wno-unused-result '
@@ -770,18 +772,18 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wformat -Werror=format-security         '
                         '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-flto=auto -ffat-lto-objects -march=x86-64 '
                         '-mtune=generic -O3 -pipe -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
                         '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-flto=auto -march=x86-64 -mtune=generic -O3 -pipe '
                         '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wformat -Werror=format-security         '
                         '-fstack-clash-protection -fcf-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-flto=auto -fno-semantic-interposition -flto '
                         '-fuse-linker-plugin -ffat-lto-objects '
                         '-flto-partition=none -g -std=c99 -Wextra '
